@@ -1,23 +1,23 @@
 /* Copyright (c) 2010, 2013 Daniel Doubrovkine, Markus Karg, All Rights Reserved
  *
- * The contents of this file is dual-licensed under 2 
- * alternative Open Source/Free licenses: LGPL 2.1 or later and 
+ * The contents of this file is dual-licensed under 2
+ * alternative Open Source/Free licenses: LGPL 2.1 or later and
  * Apache License 2.0. (starting with JNA version 4.0.0).
- * 
- * You can freely decide which license you want to apply to 
+ *
+ * You can freely decide which license you want to apply to
  * the project.
- * 
+ *
  * You may obtain a copy of the LGPL License at:
- * 
+ *
  * http://www.gnu.org/licenses/licenses.html
- * 
+ *
  * A copy is also included in the downloadable source code package
  * containing JNA, in file "LGPL2.1".
- * 
+ *
  * You may obtain a copy of the Apache License at:
- * 
+ *
  * http://www.apache.org/licenses/
- * 
+ *
  * A copy is also included in the downloadable source code package
  * containing JNA, in file "AL2.0".
  */
@@ -39,8 +39,11 @@ import com.sun.jna.Pointer;
 import com.sun.jna.platform.win32.WinNT.HANDLE;
 import com.sun.jna.platform.win32.WinNT.HANDLEByReference;
 import com.sun.jna.platform.win32.WinNT.HRESULT;
+import com.sun.jna.platform.win32.WinNT.LOGICAL_PROCESSOR_RELATIONSHIP;
+import com.sun.jna.platform.win32.WinNT.SYSTEM_LOGICAL_PROCESSOR_INFORMATION_EX;
 import com.sun.jna.ptr.IntByReference;
 import com.sun.jna.ptr.PointerByReference;
+import com.sun.jna.win32.W32APITypeMapper;
 
 /**
  * Kernel32 utility API.
@@ -175,14 +178,35 @@ public abstract class Kernel32Util implements WinDef {
         }
     }
 
+    /**
+     * Format a message from a code.
+     *
+     * @param code The error code
+     * @return Formatted message in the default locale.
+     */
+    public static String formatMessage(int code) {
+        return formatMessage(code, 0, 0);
+    }
+
     /**
      * Format a message from the value obtained from
      * {@link Kernel32#GetLastError()} or {@link Native#getLastError()}.
      *
+     * <p>If you pass in zero, FormatMessage looks for a message for LANGIDs in the following order:</p>
+     * <ol>
+     *   <li>Language neutral</li>
+     *   <li>Thread LANGID, based on the thread's locale value</li>
+     *   <li>User default LANGID, based on the user's default locale value</li>
+     *   <li>System default LANGID, based on the system default locale value</li>
+     *   <li>US English</li>
+     * </ol>
+     *
      * @param code The error code
-     * @return Formatted message.
+     * @param primaryLangId The primary language identifier
+     * @param sublangId The sublanguage identifier
+     * @return Formatted message in the specified locale.
      */
-    public static String formatMessage(int code) {
+    public static String formatMessage(int code, int primaryLangId, int sublangId) {
         PointerByReference buffer = new PointerByReference();
         int nLen = Kernel32.INSTANCE.FormatMessage(
                 WinBase.FORMAT_MESSAGE_ALLOCATE_BUFFER
@@ -190,7 +214,7 @@ public abstract class Kernel32Util implements WinDef {
                 | WinBase.FORMAT_MESSAGE_IGNORE_INSERTS,
                 null,
                 code,
-                0, // TODO: // MAKELANGID(LANG_NEUTRAL,SUBLANG_DEFAULT)
+                WinNT.LocaleMacros.MAKELANGID(primaryLangId, sublangId),
                 buffer, 0, null);
         if (nLen == 0) {
             throw new LastErrorException(Native.getLastError());
@@ -210,20 +234,25 @@ public abstract class Kernel32Util implements WinDef {
      *
      * @param code
      *            HRESULT
-     * @return Formatted message.
+     * @return Formatted message in the default locale.
      */
     public static String formatMessage(HRESULT code) {
         return formatMessage(code.intValue());
     }
 
     /**
-     * @deprecated use {@link #formatMessage(WinNT.HRESULT)} instead.
-     * @param code error code
-     * @return formatted message
+     * Format a message from an HRESULT.
+     *
+     * @param code
+     *            HRESULT
+     * @param primaryLangId
+     *            The primary language identifier
+     * @param sublangId
+     *            The primary language identifier
+     * @return Formatted message in the specified locale.
      */
-    @Deprecated
-    public static String formatMessageFromHR(HRESULT code) {
-        return formatMessage(code.intValue());
+    public static String formatMessage(HRESULT code, int primaryLangId, int sublangId) {
+        return formatMessage(code.intValue(), primaryLangId, sublangId);
     }
 
     /**
@@ -231,21 +260,45 @@ public abstract class Kernel32Util implements WinDef {
      *
      * @param code
      *            Error code, typically a result of GetLastError.
-     * @return Formatted message.
+     * @return Formatted message in the default locale.
      */
     public static String formatMessageFromLastErrorCode(int code) {
-        return formatMessageFromHR(W32Errors.HRESULT_FROM_WIN32(code));
+        return formatMessage(W32Errors.HRESULT_FROM_WIN32(code));
+    }
+
+    /**
+     * Format a system message from an error code.
+     *
+     * @param code
+     *            Error code, typically a result of GetLastError.
+     * @param primaryLangId
+     *            The primary language identifier
+     * @param sublangId
+     *            The primary language identifier
+     * @return Formatted message in the specified locale.
+     */
+    public static String formatMessageFromLastErrorCode(int code, int primaryLangId, int sublangId) {
+        return formatMessage(W32Errors.HRESULT_FROM_WIN32(code), primaryLangId, sublangId);
     }
 
     /**
      * @return Obtains the human-readable error message text from the last error
-     *         that occurred by invocating {@code Kernel32.GetLastError()}.
+     *         that occurred by invocating {@code Kernel32.GetLastError()} in the default locale.
      */
     public static String getLastErrorMessage() {
         return Kernel32Util.formatMessageFromLastErrorCode(Kernel32.INSTANCE
                 .GetLastError());
     }
 
+    /**
+     * @return Obtains the human-readable error message text from the last error
+     *         that occurred by invocating {@code Kernel32.GetLastError()} in the specified locale.
+     */
+    public static String getLastErrorMessage(int primaryLangId, int sublangId) {
+        return Kernel32Util.formatMessageFromLastErrorCode(Kernel32.INSTANCE
+                .GetLastError(), primaryLangId, sublangId);
+    }
+
     /**
      * Return the path designated for temporary files.
      *
@@ -336,28 +389,13 @@ public abstract class Kernel32Util implements WinDef {
                         default:
                             throw new Win32Exception(rc);
                     }
-                // fall-thru
-
-            default:
-                return type;
+                default:
+                    return type;
             }
-        } catch(Win32Exception e) {
-            err = e;
-            throw err;  // re-throw so finally block executed
+        } catch(final Win32Exception e) {
+            throw err = e; // re-throw to avoid return value!
         } finally {
-            try {
-                closeHandle(hFile);
-            } catch(Win32Exception e) {
-                if (err == null) {
-                    err = e;
-                } else {
-                    err.addSuppressedReflected(e);
-                }
-            }
-
-            if (err != null) {
-                throw err;
-            }
+            cleanUp(hFile, err);
         }
     }
 
@@ -432,8 +470,8 @@ public abstract class Kernel32Util implements WinDef {
         if (lpszEnvironmentBlock == null) {
             return null;
         }
-        
-        Map<String,String>  vars=new TreeMap<String,String>();
+
+        Map<String,String>  vars=new TreeMap<>();
         boolean             asWideChars=isWideCharEnvironmentStringBlock(lpszEnvironmentBlock, offset);
         long                stepFactor=asWideChars ? 2L : 1L;
         for (long    curOffset=offset; ; ) {
@@ -679,13 +717,58 @@ public abstract class Kernel32Util implements WinDef {
             }
         }
         WinNT.SYSTEM_LOGICAL_PROCESSOR_INFORMATION firstInformation = new WinNT.SYSTEM_LOGICAL_PROCESSOR_INFORMATION(
-                memory);
+            memory);
         int returnedStructCount = bufferSize.getValue().intValue()
-                / sizePerStruct;
+            / sizePerStruct;
         return (WinNT.SYSTEM_LOGICAL_PROCESSOR_INFORMATION[]) firstInformation
                 .toArray(new WinNT.SYSTEM_LOGICAL_PROCESSOR_INFORMATION[returnedStructCount]);
     }
 
+    /**
+     * Convenience method to get the processor information. Takes care of
+     * auto-growing the array and populating variable-length arrays in
+     * structures.
+     *
+     * @param relationshipType
+     *            The type of relationship to retrieve. This parameter can be
+     *            one of the following values:
+     *            {@link LOGICAL_PROCESSOR_RELATIONSHIP#RelationCache},
+     *            {@link LOGICAL_PROCESSOR_RELATIONSHIP#RelationGroup},
+     *            {@link LOGICAL_PROCESSOR_RELATIONSHIP#RelationNumaNode},
+     *            {@link LOGICAL_PROCESSOR_RELATIONSHIP#RelationProcessorCore},
+     *            {@link LOGICAL_PROCESSOR_RELATIONSHIP#RelationProcessorPackage},
+     *            or {@link LOGICAL_PROCESSOR_RELATIONSHIP#RelationAll}
+     * @return the array of processor information.
+     */
+    public static final SYSTEM_LOGICAL_PROCESSOR_INFORMATION_EX[] getLogicalProcessorInformationEx(
+            int relationshipType) {
+        WinDef.DWORDByReference bufferSize = new WinDef.DWORDByReference(new WinDef.DWORD(1));
+        Memory memory;
+        while (true) {
+            memory = new Memory(bufferSize.getValue().intValue());
+            if (!Kernel32.INSTANCE.GetLogicalProcessorInformationEx(relationshipType, memory, bufferSize)) {
+                int err = Kernel32.INSTANCE.GetLastError();
+                if (err != WinError.ERROR_INSUFFICIENT_BUFFER)
+                    throw new Win32Exception(err);
+            } else {
+                break;
+            }
+        }
+        // Array elements have variable size; iterate to populate array
+        List<SYSTEM_LOGICAL_PROCESSOR_INFORMATION_EX> procInfoList = new ArrayList<>();
+        int offset = 0;
+        while (offset < bufferSize.getValue().intValue()) {
+            SYSTEM_LOGICAL_PROCESSOR_INFORMATION_EX information = SYSTEM_LOGICAL_PROCESSOR_INFORMATION_EX
+                    .fromPointer(memory.share(offset));
+            procInfoList.add(information);
+            offset += information.size;
+        }
+        return procInfoList.toArray(new SYSTEM_LOGICAL_PROCESSOR_INFORMATION_EX[0]);
+    }
+
+    // Prevents useless heap pollution
+    private static final String[] EMPTY_STRING_ARRAY = new String[0];
+
     /**
      * Retrieves all the keys and values for the specified section of an initialization file.
      *
@@ -706,7 +789,12 @@ public abstract class Kernel32Util implements WinDef {
     public static final String[] getPrivateProfileSection(final String appName, final String fileName) {
         final char buffer[] = new char[32768]; // Maximum section size according to MSDN (http://msdn.microsoft.com/en-us/library/windows/desktop/ms724348(v=vs.85).aspx)
         if (Kernel32.INSTANCE.GetPrivateProfileSection(appName, buffer, new DWORD(buffer.length), fileName).intValue() == 0) {
-            throw new Win32Exception(Kernel32.INSTANCE.GetLastError());
+            final int lastError = Kernel32.INSTANCE.GetLastError();
+            if (lastError == Kernel32.ERROR_SUCCESS) {
+                return EMPTY_STRING_ARRAY;
+            } else {
+                throw new Win32Exception(lastError);
+            }
         }
         return new String(buffer).split("\0");
     }
@@ -812,15 +900,44 @@ public abstract class Kernel32Util implements WinDef {
      */
     public static final String extractVolumeGUID(String volumeGUIDPath) {
         if ((volumeGUIDPath == null)
-         || (volumeGUIDPath.length() <= (VOLUME_GUID_PATH_PREFIX.length() + VOLUME_GUID_PATH_SUFFIX.length()))
-         || (!volumeGUIDPath.startsWith(VOLUME_GUID_PATH_PREFIX))
-         || (!volumeGUIDPath.endsWith(VOLUME_GUID_PATH_SUFFIX))) {
+            || (volumeGUIDPath.length() <= (VOLUME_GUID_PATH_PREFIX.length() + VOLUME_GUID_PATH_SUFFIX.length()))
+            || (!volumeGUIDPath.startsWith(VOLUME_GUID_PATH_PREFIX))
+            || (!volumeGUIDPath.endsWith(VOLUME_GUID_PATH_SUFFIX))) {
             throw new IllegalArgumentException("Bad volume GUID path format: " + volumeGUIDPath);
         }
 
         return volumeGUIDPath.substring(VOLUME_GUID_PATH_PREFIX.length(), volumeGUIDPath.length() - VOLUME_GUID_PATH_SUFFIX.length());
     }
 
+    /**
+     * This function retrieves the full path of the executable file of a given process identifier.
+     *
+     * @param pid
+     *          Identifier for the running process
+     * @param dwFlags
+     *          0 - The name should use the Win32 path format.
+     *          1(WinNT.PROCESS_NAME_NATIVE) - The name should use the native system path format.
+     *
+     * @return the full path of the process's executable file of null if failed. To get extended error information,
+     *         call GetLastError.
+     */
+    public static final String QueryFullProcessImageName(int pid, int dwFlags) {
+        HANDLE hProcess = null;
+        Win32Exception we = null;
+
+        try {
+            hProcess = Kernel32.INSTANCE.OpenProcess(WinNT.PROCESS_QUERY_INFORMATION | WinNT.PROCESS_VM_READ, false, pid);
+            if (hProcess == null) {
+                throw new Win32Exception(Kernel32.INSTANCE.GetLastError());
+            }
+            return QueryFullProcessImageName(hProcess, dwFlags);
+        } catch (final Win32Exception e) {
+            throw we = e; // re-throw to avoid return value!
+        } finally {
+            cleanUp(hProcess, we);
+        }
+    }
+
     /**
      *
      * This function retrieves the full path of the executable file of a given process.
@@ -835,10 +952,16 @@ public abstract class Kernel32Util implements WinDef {
      *         call GetLastError.
      */
     public static final String QueryFullProcessImageName(HANDLE hProcess, int dwFlags) {
-        char[] path = new char[WinDef.MAX_PATH];
-        IntByReference lpdwSize = new IntByReference(path.length);
-        if (Kernel32.INSTANCE.QueryFullProcessImageName(hProcess, 0, path, lpdwSize))
-            return new String(path).substring(0, lpdwSize.getValue());
+        int size = WinDef.MAX_PATH; // Start with MAX_PATH, then increment with 1024 each iteration
+        IntByReference lpdwSize = new IntByReference();
+        do {
+            char[] lpExeName = new char[size];
+            lpdwSize.setValue(size);
+            if (Kernel32.INSTANCE.QueryFullProcessImageName(hProcess, dwFlags, lpExeName, lpdwSize)) {
+                return new String(lpExeName, 0, lpdwSize.getValue());
+            }
+            size += 1024;
+        } while (Kernel32.INSTANCE.GetLastError() == Kernel32.ERROR_INSUFFICIENT_BUFFER);
         throw new Win32Exception(Kernel32.INSTANCE.GetLastError());
     }
 
@@ -934,7 +1057,7 @@ public abstract class Kernel32Util implements WinDef {
      *
      * @param path
      *            The path to the executable file
-     * @return A map of resource type name/ID => resources.<br>
+     * @return A map of resource type name/ID =&gt; resources.<br>
      *         A map key + a single list item + the path to the executable can
      *         be handed off to getResource() to actually get the resource.
      */
@@ -945,8 +1068,8 @@ public abstract class Kernel32Util implements WinDef {
             throw new Win32Exception(Kernel32.INSTANCE.GetLastError());
         }
 
-        final List<String> types = new ArrayList<String>();
-        final Map<String, List<String>> result = new LinkedHashMap<String, List<String>>();
+        final List<String> types = new ArrayList<>();
+        final Map<String, List<String>> result = new LinkedHashMap<>();
 
         WinBase.EnumResTypeProc ertp = new WinBase.EnumResTypeProc() {
 
@@ -1057,7 +1180,7 @@ public abstract class Kernel32Util implements WinDef {
                 throw new Win32Exception(Kernel32.INSTANCE.GetLastError());
             }
 
-            List<Tlhelp32.MODULEENTRY32W> modules = new ArrayList<Tlhelp32.MODULEENTRY32W>();
+            List<Tlhelp32.MODULEENTRY32W> modules = new ArrayList<>();
             modules.add(first);
 
             Tlhelp32.MODULEENTRY32W next = new Tlhelp32.MODULEENTRY32W();
@@ -1075,23 +1198,312 @@ public abstract class Kernel32Util implements WinDef {
             }
 
             return modules;
-        } catch (Win32Exception e) {
-            we = e;
-            throw we;   // re-throw so finally block is executed
+        } catch (final Win32Exception e) {
+            throw we = e; // re-throw to avoid return value!
         } finally {
-            try {
-                closeHandle(snapshot);
-            } catch(Win32Exception e) {
-                if (we == null) {
-                    we = e;
-                } else {
-                    we.addSuppressedReflected(e);
-                }
-            }
+            cleanUp(snapshot, we);
+        }
+    }
 
-            if (we != null) {
-                throw we;
+    /**
+     * Expands environment-variable strings and replaces them with the values
+     * defined for the current user.
+     *
+     * @param input A string that contains one or more environment-variable
+     *              strings in the form: %variableName%. For each such
+     *              reference, the %variableName% portion is replaced with the
+     *              current value of that environment variable.
+     *
+     *              <p>Case is ignored when looking up the environment-variable
+     *              name. If the name is not found, the %variableName% portion
+     *              is left unexpanded.</p>
+     *
+     *              <p>Note that this function does not support all the features
+     *              that Cmd.exe supports. For example, it does not support
+     *              %variableName:str1=str2% or %variableName:~offset,length%.</p>
+     *
+     * @return the replaced string
+     * @throws Win32Exception if an error occurs
+     */
+    public static String expandEnvironmentStrings(String input) {
+        if(input == null) {
+            return "";
+        }
+
+        int resultChars = Kernel32.INSTANCE.ExpandEnvironmentStrings(input, null, 0);
+
+        if(resultChars == 0) {
+            throw new Win32Exception(Kernel32.INSTANCE.GetLastError());
+        }
+
+        Memory resultMemory;
+        if( W32APITypeMapper.DEFAULT == W32APITypeMapper.UNICODE ) {
+            resultMemory = new Memory(resultChars * Native.WCHAR_SIZE);
+        } else {
+            // return value is length in chars including terminating NULL,
+            // documentation for ANSI version says: buffer size should be the
+            // string length, plus terminating null character, plus one
+            resultMemory = new Memory(resultChars + 1);
+        }
+        resultChars = Kernel32.INSTANCE.ExpandEnvironmentStrings(input, resultMemory, resultChars);
+
+        if(resultChars == 0) {
+            throw new Win32Exception(Kernel32.INSTANCE.GetLastError());
+        }
+
+        if( W32APITypeMapper.DEFAULT == W32APITypeMapper.UNICODE ) {
+            return resultMemory.getWideString(0);
+        } else {
+            return resultMemory.getString(0);
+        }
+    }
+
+    /**
+     * Gets the priority class of the current process.
+     *
+     * @return The priority class of the current process.
+     * @throws Win32Exception if an error occurs.
+     */
+    public static DWORD getCurrentProcessPriority() {
+        final DWORD dwPriorityClass = Kernel32.INSTANCE.GetPriorityClass(Kernel32.INSTANCE.GetCurrentProcess());
+        if (!isValidPriorityClass(dwPriorityClass)) {
+            throw new Win32Exception(Kernel32.INSTANCE.GetLastError());
+        }
+        return dwPriorityClass;
+    }
+
+    /**
+     * Sets the priority class for the current process.
+     *
+     * @param dwPriorityClass The priority class for the process.
+     * @throws Win32Exception if an error occurs.
+     */
+    public static void setCurrentProcessPriority(final DWORD dwPriorityClass) {
+        if (!isValidPriorityClass(dwPriorityClass)) {
+            throw new IllegalArgumentException("The given priority value is invalid!");
+        }
+        if (!Kernel32.INSTANCE.SetPriorityClass(Kernel32.INSTANCE.GetCurrentProcess(), dwPriorityClass)) {
+            throw new Win32Exception(Kernel32.INSTANCE.GetLastError());
+        }
+    }
+
+    /**
+     * Enables or disables "background" processing mode for the current process
+     *
+     * @param enable If true, enables "background" processing mode, otherwise disables it.
+     * @throws Win32Exception if an error occurs.
+     */
+    public static void setCurrentProcessBackgroundMode(final boolean enable) {
+        // Note: PROCESS_MODE_BACKGROUN_{BEGIN,END} only works with the "current" process handle!
+        final DWORD dwPriorityClass = enable ? Kernel32.PROCESS_MODE_BACKGROUND_BEGIN : Kernel32.PROCESS_MODE_BACKGROUND_END;
+        if (!Kernel32.INSTANCE.SetPriorityClass(Kernel32.INSTANCE.GetCurrentProcess(), dwPriorityClass)) {
+            throw new Win32Exception(Kernel32.INSTANCE.GetLastError());
+        }
+    }
+
+    /**
+     * Gets the priority value of the current thread.
+     *
+     * @return The priority value of the current thread.
+     * @throws Win32Exception if an error occurs.
+     */
+    public static int getCurrentThreadPriority() {
+        final int nPriority = Kernel32.INSTANCE.GetThreadPriority(Kernel32.INSTANCE.GetCurrentThread());
+        if (!isValidThreadPriority(nPriority)) {
+            throw new Win32Exception(Kernel32.INSTANCE.GetLastError());
+        }
+        return nPriority;
+    }
+
+    /**
+     * Sets the priority value for the current thread.
+     *
+     * @param nPriority The priority value for the thread.
+     * @throws Win32Exception if an error occurs.
+     */
+    public static void setCurrentThreadPriority(final int nPriority) {
+        if (!isValidThreadPriority(nPriority)) {
+            throw new IllegalArgumentException("The given priority value is invalid!");
+        }
+        if (!Kernel32.INSTANCE.SetThreadPriority(Kernel32.INSTANCE.GetCurrentThread(), nPriority)) {
+            throw new Win32Exception(Kernel32.INSTANCE.GetLastError());
+        }
+    }
+
+    /**
+     * Enables or disables "background" processing mode for the current thread
+     *
+     * @param enable If true, enables "background" processing mode, otherwise disables it.
+     * @throws Win32Exception if an error occurs.
+     */
+    public static void setCurrentThreadBackgroundMode(final boolean enable) {
+        // Note: THREAD_MODE_BACKGROUND_{BEGIN,END} only works with the "current" thread handle!
+        final int nPriority = enable ? Kernel32.THREAD_MODE_BACKGROUND_BEGIN : Kernel32.THREAD_MODE_BACKGROUND_END;
+        if (!Kernel32.INSTANCE.SetThreadPriority(Kernel32.INSTANCE.GetCurrentThread(), nPriority)) {
+            throw new Win32Exception(Kernel32.INSTANCE.GetLastError());
+        }
+    }
+
+    /**
+     * Gets the priority class of the specified process.
+     *
+     * @param pid Identifier for the running process.
+     * @throws Win32Exception if an error occurs.
+     */
+    public static DWORD getProcessPriority(final int pid) {
+        final HANDLE hProcess = Kernel32.INSTANCE.OpenProcess(WinNT.PROCESS_QUERY_INFORMATION , false, pid);
+        if (hProcess == null) {
+            throw new Win32Exception(Kernel32.INSTANCE.GetLastError());
+        }
+
+        Win32Exception we = null;
+        try {
+            final DWORD dwPriorityClass = Kernel32.INSTANCE.GetPriorityClass(hProcess);
+            if (!isValidPriorityClass(dwPriorityClass)) {
+                throw new Win32Exception(Kernel32.INSTANCE.GetLastError());
             }
+            return dwPriorityClass;
+        } catch (final Win32Exception e) {
+            throw we = e; // re-throw to avoid return value!
+        } finally {
+            cleanUp(hProcess, we);
+        }
+    }
+
+    /**
+     * Sets the priority class for the specified process.
+     *
+     * @param pid Identifier for the running process.
+     * @param dwPriorityClass The priority class for the process.
+     * @throws Win32Exception if an error occurs.
+     */
+    public static void setProcessPriority(final int pid, final DWORD dwPriorityClass) {
+        if (!isValidPriorityClass(dwPriorityClass)) {
+            throw new IllegalArgumentException("The given priority value is invalid!");
+        }
+
+        final HANDLE hProcess = Kernel32.INSTANCE.OpenProcess(WinNT.PROCESS_SET_INFORMATION, false, pid);
+        if (hProcess == null) {
+            throw new Win32Exception(Kernel32.INSTANCE.GetLastError());
+        }
+
+        Win32Exception we = null;
+        try {
+            if (!Kernel32.INSTANCE.SetPriorityClass(hProcess, dwPriorityClass)) {
+                throw new Win32Exception(Kernel32.INSTANCE.GetLastError());
+            }
+        } catch (final Win32Exception e) {
+            we = e;
+        } finally {
+            cleanUp(hProcess, we);
+        }
+    }
+
+    /**
+     * Gets the priority value of the specified thread.
+     *
+     * @param tid Identifier for the running thread.
+     * @throws Win32Exception if an error occurs.
+     */
+    public static int getThreadPriority(final int tid) {
+        final HANDLE hThread = Kernel32.INSTANCE.OpenThread(WinNT.THREAD_QUERY_INFORMATION, false, tid);
+        if (hThread == null) {
+            throw new Win32Exception(Kernel32.INSTANCE.GetLastError());
+        }
+
+        Win32Exception we = null;
+        try {
+            final int nPriority = Kernel32.INSTANCE.GetThreadPriority(hThread);
+            if (!isValidThreadPriority(nPriority)) {
+                throw new Win32Exception(Kernel32.INSTANCE.GetLastError());
+            }
+            return nPriority;
+        } catch (final Win32Exception e) {
+            throw we = e; // re-throw to avoid return value!
+        } finally {
+            cleanUp(hThread, we);
+        }
+    }
+
+    /**
+     * Sets the priority value for the specified thread.
+     *
+     * @param tid Identifier for the running thread.
+     * @param nPriority The priority value for the thread.
+     * @throws Win32Exception if an error occurs.
+     */
+    public static void setThreadPriority(final int tid, final int nPriority) {
+        if (!isValidThreadPriority(nPriority)) {
+            throw new IllegalArgumentException("The given priority value is invalid!");
+        }
+
+        final HANDLE hThread = Kernel32.INSTANCE.OpenThread(WinNT.THREAD_SET_INFORMATION, false, tid);
+        if (hThread == null) {
+            throw new Win32Exception(Kernel32.INSTANCE.GetLastError());
+        }
+
+        Win32Exception we = null;
+        try {
+            if (!Kernel32.INSTANCE.SetThreadPriority(hThread, nPriority)) {
+                throw new Win32Exception(Kernel32.INSTANCE.GetLastError());
+            }
+        } catch (final Win32Exception e) {
+            we = e;
+        } finally {
+            cleanUp(hThread, we);
+        }
+    }
+
+    /**
+     * Test whether the given priority class is valid.
+     * <p>Intentionally does not accept "background" processing mode flags!</p>
+     *
+     * @param dwPriorityClass The priority value to test.
+     * @return Returns true, if and only if the given priority value was valid
+     */
+    public static boolean isValidPriorityClass(final DWORD dwPriorityClass) {
+        return Kernel32.NORMAL_PRIORITY_CLASS.equals(dwPriorityClass) ||
+            Kernel32.IDLE_PRIORITY_CLASS.equals(dwPriorityClass) ||
+            Kernel32.HIGH_PRIORITY_CLASS.equals(dwPriorityClass) ||
+            Kernel32.REALTIME_PRIORITY_CLASS.equals(dwPriorityClass) ||
+            Kernel32.BELOW_NORMAL_PRIORITY_CLASS.equals(dwPriorityClass) ||
+            Kernel32.ABOVE_NORMAL_PRIORITY_CLASS.equals(dwPriorityClass);
+    }
+
+    /**
+     * Test whether the given thread priority is valid.
+     * <p>Intentionally does not accept "background" processing mode flags!</p>
+     *
+     * @param nPriority The priority value to test.
+     * @return Returns true, if and only if the given priority value was valid
+     */
+    public static boolean isValidThreadPriority(final int nPriority) {
+        switch(nPriority) {
+            case Kernel32.THREAD_PRIORITY_IDLE:
+            case Kernel32.THREAD_PRIORITY_LOWEST:
+            case Kernel32.THREAD_PRIORITY_BELOW_NORMAL:
+            case Kernel32.THREAD_PRIORITY_NORMAL:
+            case Kernel32.THREAD_PRIORITY_ABOVE_NORMAL:
+            case Kernel32.THREAD_PRIORITY_HIGHEST:
+            case Kernel32.THREAD_PRIORITY_TIME_CRITICAL:
+                return true;
+            default:
+                return false;
+        }
+    }
+
+    private static void cleanUp(final HANDLE h, Win32Exception we) {
+        try {
+            closeHandle(h);
+        } catch (final Win32Exception e) {
+            if (we == null) {
+                we = e;
+            } else {
+                we.addSuppressedReflected(e);
+            }
+        }
+        if (we != null) {
+            throw we;
         }
     }
 }
