@@ -23,18 +23,20 @@
  */
 package com.sun.jna;
 
-import junit.framework.*;
-import java.lang.reflect.Method;
 import java.io.File;
+import java.lang.reflect.Method;
 import java.net.MalformedURLException;
 import java.net.URL;
 import java.net.URLClassLoader;
+import java.nio.charset.Charset;
 import java.util.Arrays;
 import java.util.Collections;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 
+import junit.framework.TestCase;
+
 //@SuppressWarnings("unused")
 public class DirectTest extends TestCase implements Paths {
 
@@ -202,8 +204,8 @@ public class DirectTest extends TestCase implements Paths {
         };
         final TypeMapper mapper = new DefaultTypeMapper();
         final int alignment = Structure.ALIGN_NONE;
-        final String encoding = System.getProperty("file.encoding");
-        Map<String, Object> options = new HashMap<String, Object>();
+        final String encoding = Charset.defaultCharset().name();
+        Map<String, Object> options = new HashMap<>();
         options.put(Library.OPTION_TYPE_MAPPER, mapper);
         options.put(Library.OPTION_STRUCTURE_ALIGNMENT, alignment);
         options.put(Library.OPTION_STRING_ENCODING, encoding);
@@ -223,7 +225,7 @@ public class DirectTest extends TestCase implements Paths {
     public static class DirectMappingStatic {
         final static TypeMapper TEST_MAPPER = new DefaultTypeMapper();
         final static int TEST_ALIGNMENT = Structure.ALIGN_DEFAULT;
-        final static String TEST_ENCODING = System.getProperty("file.encoding");
+        final static String TEST_ENCODING = Charset.defaultCharset().name();
         final static Map<String, Object> TEST_OPTIONS = new HashMap<String, Object>() {
             private static final long serialVersionUID = 1L;    // we're not serializing it
 
