@@ -1,23 +1,23 @@
 /* Copyright (c) 2009 Timothy Wall, All Rights Reserved
  *
- * The contents of this file is dual-licensed under 2 
- * alternative Open Source/Free licenses: LGPL 2.1 or later and 
+ * The contents of this file is dual-licensed under 2
+ * alternative Open Source/Free licenses: LGPL 2.1 or later and
  * Apache License 2.0. (starting with JNA version 4.0.0).
- * 
- * You can freely decide which license you want to apply to 
+ *
+ * You can freely decide which license you want to apply to
  * the project.
- * 
+ *
  * You may obtain a copy of the LGPL License at:
- * 
+ *
  * http://www.gnu.org/licenses/licenses.html
- * 
+ *
  * A copy is also included in the downloadable source code package
  * containing JNA, in file "LGPL2.1".
- * 
+ *
  * You may obtain a copy of the Apache License at:
- * 
+ *
  * http://www.apache.org/licenses/
- * 
+ *
  * A copy is also included in the downloadable source code package
  * containing JNA, in file "AL2.0".
  */
@@ -249,10 +249,13 @@ public class DirectTypeMapperTest extends TestCase {
             Enumeration(int code) { this.code = code; }
             public int getCode() { return code; }
             public static Enumeration fromCode(int code) {
-                switch(code) {
-                case 0: return STATUS_0;
-                case 1: return STATUS_1;
-                default: return STATUS_ERROR;
+                switch (code) {
+                    case 0:
+                        return STATUS_0;
+                    case 1:
+                        return STATUS_1;
+                    default:
+                        return STATUS_ERROR;
                 }
             }
         }
